@@ -463,6 +463,10 @@ def get_jedi_script_from_document(document, locals, globals):
         # Invalid cursor position.
         # ValueError('`column` parameter is not in a valid range.')
         return None
+    except AttributeError:
+        # Workaround for #65: https://github.com/jonathanslenders/python-prompt-toolkit/issues/65
+        # See also: https://github.com/davidhalter/jedi/issues/508
+        return None
 
 
 class PythonCompleter(Completer):
@@ -487,6 +491,9 @@ class PythonCompleter(Completer):
                 # Issue #43: UnicodeDecodeError on OpenBSD
                 # https://github.com/jonathanslenders/python-prompt-toolkit/issues/43
                 pass
+            except AttributeError:
+                # Jedi issue #513: https://github.com/davidhalter/jedi/issues/513
+                pass
             else:
                 for c in completions:
                     yield Completion(c.name_with_symbols, len(c.complete) - len(c.name_with_symbols),
@@ -503,6 +510,7 @@ class PythonCommandLineInterface(CommandLineInterface):
                  always_multiline=False,
 
                  # For internal use.
+                 _left_margin=None,
                  _completer=None,
                  _validator=None):
 
@@ -511,6 +519,7 @@ class PythonCommandLineInterface(CommandLineInterface):
         self.always_multiline = always_multiline
         self.autocompletion_style = autocompletion_style
 
+        left_margin = _left_margin or PythonLeftMargin()
         self.completer = _completer or PythonCompleter(self.get_globals, self.get_locals)
         validator = _validator or PythonValidator()
 
@@ -518,7 +527,7 @@ class PythonCommandLineInterface(CommandLineInterface):
             input_processors=[BracketsMismatchProcessor()],
             min_height=7,
             lexer=PythonLexer,
-            left_margin=PythonLeftMargin(),
+            left_margin=left_margin,
             menus=[CompletionsMenu()] if autocompletion_style == AutoCompletionStyle.POPUP_MENU else [],
             bottom_toolbars=[
                 ArgToolbar(),
